@@ -4,7 +4,7 @@ use Moose;
 use Chart::Plotly::Trace::Attribute::Line;
 use Chart::Plotly::Trace::Attribute::Marker;
 
-our $VERSION = '0.010';    # VERSION
+our $VERSION = '0.011';    # VERSION
 
 sub TO_JSON {
     my $self = shift;
@@ -61,7 +61,7 @@ has lon => ( is            => 'rw',
              documentation => "Sets the longitude coordinates (in degrees East).", );
 
 has marker => ( is  => 'rw',
-                isa => "Maybe[HashRef]|Chart::Plotly::Trace::Attribute::Marker" );
+                isa => "Maybe[HashRef]|Maybe[ArrayRef]|Chart::Plotly::Trace::Attribute::Marker" );
 
 has mode => (
     is => 'rw',
@@ -109,7 +109,7 @@ Chart::Plotly::Trace::Scattergeo
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -253,7 +253,7 @@ Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016 by Pablo Rodríguez González.
+This software is Copyright (c) 2016 by Pablo Rodríguez González.
 
 This is free software, licensed under:
 
